﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace DatePickerDemo
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            //Bloqueamos las fechas pasadas
            fechaSalida.BlackoutDates.AddDatesInPast();
            fechaRegreso.BlackoutDates.AddDatesInPast();

            fechaSalida.SelectedDateChanged += 
                new EventHandler<SelectionChangedEventArgs>(fechaSalida_SelectedDateChanged);
            fechaRegreso.SelectedDateChanged += 
                new EventHandler<SelectionChangedEventArgs>(fechaRegreso_SelectedDateChanged);
            fechaSalida.DateValidationError += 
                new EventHandler<DatePickerDateValidationErrorEventArgs>(fecha_DateValidationError);
            fechaRegreso.DateValidationError += 
                new EventHandler<DatePickerDateValidationErrorEventArgs>(fecha_DateValidationError);

            botonReservar.Click += new RoutedEventHandler(botonReservar_Click);
        }

        void botonReservar_Click(object sender, RoutedEventArgs e)
        {
            if (fechaSalida.SelectedDate.HasValue && fechaRegreso.SelectedDate.HasValue)
            {
                textoConfirmacion.Text =
                    String.Format("Reservación exitosa saliendo el {0} y regresando el {1}. ¡Buen viaje!",
                    fechaSalida.SelectedDate.GetValueOrDefault().ToLongDateString(),
                    fechaRegreso.SelectedDate.GetValueOrDefault().ToLongDateString());
            }
            else
            {
                if (!fechaSalida.SelectedDate.HasValue)
                {
                    textoErrorSalida.Text = "Selecciona una fecha";
                }
                if (!fechaRegreso.SelectedDate.HasValue)
                {
                    textoErrorRegreso.Text = "Selecciona una fecha";
                }
            }
        }

        void fechaRegreso_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            textoErrorRegreso.Text = "";
        }

        void fecha_DateValidationError(object sender, DatePickerDateValidationErrorEventArgs e)
        {
            DatePicker pick = (DatePicker)sender;
            if (pick == fechaSalida)
            {
                textoErrorSalida.Text = "La fecha no es válida";
            }
            else
            {
                textoErrorRegreso.Text = "La fecha no es válida";
            }
        }

        void fechaSalida_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            //Reiniciamos mensaje de error
            textoErrorSalida.Text = "";

            //Reiniciamos las BlackoutDates
            fechaRegreso.BlackoutDates.Clear();
            fechaRegreso.BlackoutDates.AddDatesInPast();

            if (fechaSalida.SelectedDate > fechaRegreso.SelectedDate)
            {
                fechaRegreso.SelectedDate = null;
            }

            if (fechaSalida.SelectedDate == DateTime.Today)
            {
                //No hacemos nada
            }
            else //Evitamos que la fecha de regreso pueda ser menor a la de salida
            {
                //Agregamos las necesarias
                DateTime fechaSalidaActual = fechaSalida.SelectedDate.GetValueOrDefault();
                CalendarDateRange rangoBlackout =
                    new CalendarDateRange(DateTime.Today, fechaSalidaActual.AddDays(-1));
                fechaRegreso.BlackoutDates.Add(rangoBlackout);
            }
        }
    }
}
